==> jc-1.4.0.tar.gz: gnu/java/beans/decoder/DefaultExceptionListener.h <==
// public class gnu.java.beans.decoder.DefaultExceptionListener

// class file dependencies
// @dep_class 2a7bfd73a7db6cd1 gnu_java_beans_decoder_DefaultExceptionListener
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_beans_decoder_DefaultExceptionListener_H_
#define _JC_gnu_java_beans_decoder_DefaultExceptionListener_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Exception$object;

// Typedefs
typedef struct _jc_gnu_java_beans_decoder_DefaultExceptionListener$sub_refs	_jc_gnu_java_beans_decoder_DefaultExceptionListener$sub_refs;
typedef struct _jc_gnu_java_beans_decoder_DefaultExceptionListener$sub_nonrefs	_jc_gnu_java_beans_decoder_DefaultExceptionListener$sub_nonrefs;
typedef struct _jc_gnu_java_beans_decoder_DefaultExceptionListener$refs	_jc_gnu_java_beans_decoder_DefaultExceptionListener$refs;
typedef struct _jc_gnu_java_beans_decoder_DefaultExceptionListener$nonrefs	_jc_gnu_java_beans_decoder_DefaultExceptionListener$nonrefs;
typedef struct _jc_gnu_java_beans_decoder_DefaultExceptionListener$object	_jc_gnu_java_beans_decoder_DefaultExceptionListener$object;

typedef const struct _jc_gnu_java_beans_decoder_DefaultExceptionListener$vmethods	_jc_gnu_java_beans_decoder_DefaultExceptionListener$vmethods;
typedef const struct _jc_gnu_java_beans_decoder_DefaultExceptionListener$vtable	_jc_gnu_java_beans_decoder_DefaultExceptionListener$vtable;
typedef const struct _jc_gnu_java_beans_decoder_DefaultExceptionListener$vtype	_jc_gnu_java_beans_decoder_DefaultExceptionListener$vtype;

// Constructors
extern void _jc_gnu_java_beans_decoder_DefaultExceptionListener$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_beans_decoder_DefaultExceptionListener$object *);

// Virtual methods
extern void _jc_gnu_java_beans_decoder_DefaultExceptionListener$method$exceptionThrown$57842b24668040b0(_jc_env *, struct _jc_gnu_java_beans_decoder_DefaultExceptionListener$object *, struct _jc_java_lang_Exception$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_beans_decoder_DefaultExceptionListener$method_info$exceptionThrown$57842b24668040b0;

// Virtual methods structure
struct _jc_gnu_java_beans_decoder_DefaultExceptionListener$vmethods {
	void	(*exceptionThrown$57842b24668040b0)(_jc_env *, struct _jc_gnu_java_beans_decoder_DefaultExceptionListener$object *, struct _jc_java_lang_Exception$object *);
};

// Vtable
struct _jc_gnu_java_beans_decoder_DefaultExceptionListener$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_beans_decoder_DefaultExceptionListener$vmethods	gnu_java_beans_decoder_DefaultExceptionListener;
};

// Vtype
struct _jc_gnu_java_beans_decoder_DefaultExceptionListener$vtype {
	_jc_type			type;
	_jc_gnu_java_beans_decoder_DefaultExceptionListener$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_DefaultExceptionListener$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_beans_decoder_DefaultExceptionListener$refs {
    _jc_gnu_java_beans_decoder_DefaultExceptionListener$sub_refs	gnu_java_beans_decoder_DefaultExceptionListener;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_DefaultExceptionListener$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_beans_decoder_DefaultExceptionListener$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_beans_decoder_DefaultExceptionListener$sub_nonrefs	gnu_java_beans_decoder_DefaultExceptionListener;
};

// Object instance structure
struct _jc_gnu_java_beans_decoder_DefaultExceptionListener$object {
	_jc_gnu_java_beans_decoder_DefaultExceptionListener$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_beans_decoder_DefaultExceptionListener$vtype	*vtype;
	_jc_gnu_java_beans_decoder_DefaultExceptionListener$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_beans_decoder_DefaultExceptionListener$vtype _jc_gnu_java_beans_decoder_DefaultExceptionListener$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_beans_decoder_DefaultExceptionListener, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_beans_decoder_DefaultExceptionListener$class_object;

#endif	/* _JC_gnu_java_beans_decoder_DefaultExceptionListener_H_ */

==> jc-1.4.6.tar.gz: gnu/java/beans/decoder/DefaultExceptionListener.h <==
// public class gnu.java.beans.decoder.DefaultExceptionListener

// class file dependencies
// @dep_class 2a7bfd73a7db6cd1 gnu_java_beans_decoder_DefaultExceptionListener
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_beans_decoder_DefaultExceptionListener_H_
#define _JC_gnu_java_beans_decoder_DefaultExceptionListener_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Exception$object;

// Typedefs
typedef struct _jc_gnu_java_beans_decoder_DefaultExceptionListener$sub_refs	_jc_gnu_java_beans_decoder_DefaultExceptionListener$sub_refs;
typedef struct _jc_gnu_java_beans_decoder_DefaultExceptionListener$sub_nonrefs	_jc_gnu_java_beans_decoder_DefaultExceptionListener$sub_nonrefs;
typedef struct _jc_gnu_java_beans_decoder_DefaultExceptionListener$refs	_jc_gnu_java_beans_decoder_DefaultExceptionListener$refs;
typedef struct _jc_gnu_java_beans_decoder_DefaultExceptionListener$nonrefs	_jc_gnu_java_beans_decoder_DefaultExceptionListener$nonrefs;
typedef struct _jc_gnu_java_beans_decoder_DefaultExceptionListener$object	_jc_gnu_java_beans_decoder_DefaultExceptionListener$object;

typedef const struct _jc_gnu_java_beans_decoder_DefaultExceptionListener$vmethods	_jc_gnu_java_beans_decoder_DefaultExceptionListener$vmethods;
typedef const struct _jc_gnu_java_beans_decoder_DefaultExceptionListener$vtable	_jc_gnu_java_beans_decoder_DefaultExceptionListener$vtable;
typedef const struct _jc_gnu_java_beans_decoder_DefaultExceptionListener$vtype	_jc_gnu_java_beans_decoder_DefaultExceptionListener$vtype;

// Constructors
extern void _jc_gnu_java_beans_decoder_DefaultExceptionListener$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_beans_decoder_DefaultExceptionListener$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_java_beans_decoder_DefaultExceptionListener$method$exceptionThrown$57842b24668040b0(_jc_env *, struct _jc_gnu_java_beans_decoder_DefaultExceptionListener$object *, struct _jc_java_lang_Exception$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_beans_decoder_DefaultExceptionListener$method_info$exceptionThrown$57842b24668040b0;

// Virtual methods structure
struct _jc_gnu_java_beans_decoder_DefaultExceptionListener$vmethods {
	void	(*exceptionThrown$57842b24668040b0)(_jc_env *, struct _jc_gnu_java_beans_decoder_DefaultExceptionListener$object *, struct _jc_java_lang_Exception$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_beans_decoder_DefaultExceptionListener$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_beans_decoder_DefaultExceptionListener$vmethods	gnu_java_beans_decoder_DefaultExceptionListener;
};

// Vtype
struct _jc_gnu_java_beans_decoder_DefaultExceptionListener$vtype {
	_jc_type			type;
	_jc_gnu_java_beans_decoder_DefaultExceptionListener$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_DefaultExceptionListener$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_beans_decoder_DefaultExceptionListener$refs {
    _jc_gnu_java_beans_decoder_DefaultExceptionListener$sub_refs	gnu_java_beans_decoder_DefaultExceptionListener;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_DefaultExceptionListener$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_beans_decoder_DefaultExceptionListener$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_beans_decoder_DefaultExceptionListener$sub_nonrefs	gnu_java_beans_decoder_DefaultExceptionListener;
};

// Object instance structure
struct _jc_gnu_java_beans_decoder_DefaultExceptionListener$object {
	_jc_gnu_java_beans_decoder_DefaultExceptionListener$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_beans_decoder_DefaultExceptionListener$vtype	*vtype;
	_jc_gnu_java_beans_decoder_DefaultExceptionListener$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_beans_decoder_DefaultExceptionListener$vtype _jc_gnu_java_beans_decoder_DefaultExceptionListener$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_beans_decoder_DefaultExceptionListener, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_beans_decoder_DefaultExceptionListener$class_object;

#endif	/* _JC_gnu_java_beans_decoder_DefaultExceptionListener_H_ */
